@@ -1,7 +1,11 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-/* exported Dialog, MessageDialogContent, ListSection, ListSectionItem */
 
-const { Clutter, GLib, GObject, Meta, Pango, St } = imports.gi;
+import Clutter from 'gi://Clutter';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Meta from 'gi://Meta';
+import Pango from 'gi://Pango';
+import St from 'gi://St';
 
 function _setLabel(label, value) {
     label.set({
@@ -10,7 +14,7 @@ function _setLabel(label, value) {
     });
 }
 
-var Dialog = GObject.registerClass(
+export const Dialog = GObject.registerClass(
 class Dialog extends St.Widget {
     _init(parentActor, styleClass) {
         super._init({
@@ -54,7 +58,7 @@ class Dialog extends St.Widget {
         this._dialog.add_child(this.contentLayout);
 
         this.buttonLayout = new St.Widget({
-            layout_manager: new Clutter.BoxLayout({ homogeneous: true }),
+            layout_manager: new Clutter.BoxLayout({homogeneous: true}),
         });
         this._dialog.add_child(this.buttonLayout);
     }
@@ -68,21 +72,21 @@ class Dialog extends St.Widget {
     }
 
     vfunc_event(event) {
-        if (event.type() == Clutter.EventType.KEY_PRESS) {
+        if (event.type() === Clutter.EventType.KEY_PRESS) {
             this._pressedKey = event.get_key_symbol();
-        } else if (event.type() == Clutter.EventType.KEY_RELEASE) {
+        } else if (event.type() === Clutter.EventType.KEY_RELEASE) {
             let pressedKey = this._pressedKey;
             this._pressedKey = null;
 
             let symbol = event.get_key_symbol();
-            if (symbol != pressedKey)
+            if (symbol !== pressedKey)
                 return Clutter.EVENT_PROPAGATE;
 
             let buttonInfo = this._buttonKeys[symbol];
             if (!buttonInfo)
                 return Clutter.EVENT_PROPAGATE;
 
-            let { button, action } = buttonInfo;
+            let {button, action} = buttonInfo;
 
             if (action && button.reactive) {
                 action();
@@ -107,7 +111,7 @@ class Dialog extends St.Widget {
     }
 
     addButton(buttonInfo) {
-        let { label, action, key } = buttonInfo;
+        let {label, action, key} = buttonInfo;
         let isDefault = buttonInfo['default'];
         let keys;
 
@@ -151,7 +155,7 @@ class Dialog extends St.Widget {
     }
 });
 
-var MessageDialogContent = GObject.registerClass({
+export const MessageDialogContent = GObject.registerClass({
     Properties: {
         'title': GObject.ParamSpec.string(
             'title', 'title', 'title',
@@ -166,8 +170,8 @@ var MessageDialogContent = GObject.registerClass({
     },
 }, class MessageDialogContent extends St.BoxLayout {
     _init(params) {
-        this._title = new St.Label({ style_class: 'message-dialog-title' });
-        this._description = new St.Label({ style_class: 'message-dialog-description' });
+        this._title = new St.Label({style_class: 'message-dialog-title'});
+        this._description = new St.Label({style_class: 'message-dialog-description'});
 
         this._description.clutter_text.ellipsize = Pango.EllipsizeMode.NONE;
         this._description.clutter_text.line_wrap = true;
@@ -243,7 +247,7 @@ var MessageDialogContent = GObject.registerClass({
     }
 });
 
-var ListSection = GObject.registerClass({
+export const ListSection = GObject.registerClass({
     Properties: {
         'title': GObject.ParamSpec.string(
             'title', 'title', 'title',
@@ -253,7 +257,7 @@ var ListSection = GObject.registerClass({
     },
 }, class ListSection extends St.BoxLayout {
     _init(params) {
-        this._title = new St.Label({ style_class: 'dialog-list-title' });
+        this._title = new St.Label({style_class: 'dialog-list-title'});
 
         this._listScrollView = new St.ScrollView({
             style_class: 'dialog-list-scrollview',
@@ -288,7 +292,7 @@ var ListSection = GObject.registerClass({
     }
 });
 
-var ListSectionItem = GObject.registerClass({
+export const ListSectionItem = GObject.registerClass({
     Properties: {
         'icon-actor':  GObject.ParamSpec.object(
             'icon-actor', 'icon-actor', 'Icon actor',
@@ -315,7 +319,7 @@ var ListSectionItem = GObject.registerClass({
             y_align: Clutter.ActorAlign.CENTER,
         });
 
-        this._title = new St.Label({ style_class: 'dialog-list-item-title' });
+        this._title = new St.Label({style_class: 'dialog-list-item-title'});
 
         this._description = new St.Label({
             style_class: 'dialog-list-item-title-description',
@@ -324,7 +328,7 @@ var ListSectionItem = GObject.registerClass({
         textLayout.add_child(this._title);
         textLayout.add_child(this._description);
 
-        let defaultParams = { style_class: 'dialog-list-item' };
+        let defaultParams = {style_class: 'dialog-list-item'};
         super._init(Object.assign(defaultParams, params));
 
         this.label_actor = this._title;
