@@ -1,51 +1,56 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-/* exported addDragMonitor, removeDragMonitor, makeDraggable */
 
-const { Clutter, GLib, Meta, Shell, St } = imports.gi;
-const Signals = imports.misc.signals;
+import Clutter from 'gi://Clutter';
+import GLib from 'gi://GLib';
+import Meta from 'gi://Meta';
+import Shell from 'gi://Shell';
+import St from 'gi://St';
+import * as Signals from '../misc/signals.js';
 
-const Main = imports.ui.main;
-const Params = imports.misc.params;
+import * as Main from './main.js';
+import * as Params from '../misc/params.js';
 
 // Time to scale down to maxDragActorSize
-var SCALE_ANIMATION_TIME = 250;
+const SCALE_ANIMATION_TIME = 250;
 // Time to animate to original position on cancel
-var SNAP_BACK_ANIMATION_TIME = 250;
+const SNAP_BACK_ANIMATION_TIME = 250;
 // Time to animate to original position on success
-var REVERT_ANIMATION_TIME = 750;
+const REVERT_ANIMATION_TIME = 750;
 
-var DragMotionResult = {
+/** @enum {number} */
+export const DragMotionResult = {
     NO_DROP:   0,
     COPY_DROP: 1,
     MOVE_DROP: 2,
     CONTINUE:  3,
 };
 
-var DragState = {
+/** @enum {number} */
+const DragState = {
     INIT:      0,
     DRAGGING:  1,
     CANCELLED: 2,
 };
 
-var DRAG_CURSOR_MAP = {
+const DRAG_CURSOR_MAP = {
     0: Meta.Cursor.DND_UNSUPPORTED_TARGET,
     1: Meta.Cursor.DND_COPY,
     2: Meta.Cursor.DND_MOVE,
 };
 
-var DragDropResult = {
+export const DragDropResult = {
     FAILURE:  0,
     SUCCESS:  1,
     CONTINUE: 2,
 };
-var dragMonitors = [];
+export const dragMonitors = [];
 
 let eventHandlerActor = null;
 let currentDraggable = null;
 
 function _getEventHandlerActor() {
     if (!eventHandlerActor) {
-        eventHandlerActor = new Clutter.Actor({ width: 0, height: 0, reactive: true });
+        eventHandlerActor = new Clutter.Actor({width: 0, height: 0, reactive: true});
         Main.uiGroup.add_actor(eventHandlerActor);
         // We connect to 'event' rather than 'captured-event' because the capturing phase doesn't happen
         // when you've grabbed the pointer.
@@ -65,20 +70,31 @@ function _getRealActorScale(actor) {
     return scale;
 }
 
-function addDragMonitor(monitor) {
+/**
+ * @typedef {object} DragMonitor
+ * @property {Function} dragMotion
+ */
+
+/**
+ * @param {DragMonitor} monitor
+ */
+export function addDragMonitor(monitor) {
     dragMonitors.push(monitor);
 }
 
-function removeDragMonitor(monitor) {
+/**
+ * @param {DragMonitor} monitor
+ */
+export function removeDragMonitor(monitor) {
     for (let i = 0; i < dragMonitors.length; i++) {
-        if (dragMonitors[i] == monitor) {
+        if (dragMonitors[i] === monitor) {
             dragMonitors.splice(i, 1);
             return;
         }
     }
 }
 
-var _Draggable = class _Draggable extends Signals.EventEmitter {
+class _Draggable extends Signals.EventEmitter {
     constructor(actor, params) {
         super();
 
@@ -95,15 +111,15 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
 
         if (!params.manualMode) {
             this.actor.connect('button-press-event',
-                               this._onButtonPress.bind(this));
+                this._onButtonPress.bind(this));
             this.actor.connect('touch-event',
-                               this._onTouchEvent.bind(this));
+                this._onTouchEvent.bind(this));
         }
 
         this.actor.connect('destroy', () => {
             this._actorDestroyed = true;
 
-            if (this._dragState == DragState.DRAGGING && this._dragCancellable)
+            if (this._dragState === DragState.DRAGGING && this._dragCancellable)
                 this._cancelDrag(global.get_current_time());
             this.disconnectAll();
         });
@@ -119,8 +135,52 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
         this._dragCancellable = true;
     }
 
+    /**
+     * addClickAction:
+     *
+     * @param {Clutter.ClickAction} action - click action to add to draggable actor
+     *
+     * Add @action to the draggable's actor, and set it up so that it does not
+     * impede drag operations.
+     */
+    addClickAction(action) {
+        action.connect('clicked', () => (this._actionClicked = true));
+        action.connect('long-press', (a, actor, state) => {
+            if (state !== Clutter.LongPressState.CANCEL)
+                return true;
+
+            const event = Clutter.get_current_event();
+            this._dragTouchSequence = event.get_event_sequence();
+
+            if (this._longPressLater)
+                return true;
+
+            // A click cancels a long-press before any click handler is
+            // run - make sure to not start a drag in that case
+            const laters = global.compositor.get_laters();
+            this._longPressLater = laters.add(Meta.LaterType.BEFORE_REDRAW, () => {
+                delete this._longPressLater;
+                if (this._actionClicked) {
+                    delete this._actionClicked;
+                    return GLib.SOURCE_REMOVE;
+                }
+                action.release();
+                this.startDrag(
+                    ...action.get_coords(),
+                    event.get_time(),
+                    this._dragTouchSequence,
+                    event.get_device());
+
+                return GLib.SOURCE_REMOVE;
+            });
+            return true;
+        });
+
+        this.actor.add_action(action);
+    }
+
     _onButtonPress(actor, event) {
-        if (event.get_button() != 1)
+        if (event.get_button() !== 1)
             return Clutter.EVENT_PROPAGATE;
 
         this._grabActor(event.get_device());
@@ -145,7 +205,7 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
         if (!Meta.is_wayland_compositor())
             return Clutter.EVENT_PROPAGATE;
 
-        if (event.type() != Clutter.EventType.TOUCH_BEGIN ||
+        if (event.type() !== Clutter.EventType.TOUCH_BEGIN ||
             !global.display.is_pointer_emulating_sequence(event.get_event_sequence()))
             return Clutter.EVENT_PROPAGATE;
 
@@ -178,7 +238,7 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
     _grabActor(device, touchSequence) {
         this._grabDevice(this.actor, device, touchSequence);
         this._onEventId = this.actor.connect('event',
-                                             this._onEvent.bind(this));
+            this._onEvent.bind(this));
     }
 
     _ungrabActor() {
@@ -211,15 +271,15 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
     }
 
     _eventIsRelease(event) {
-        if (event.type() == Clutter.EventType.BUTTON_RELEASE) {
+        if (event.type() === Clutter.EventType.BUTTON_RELEASE) {
             let buttonMask = Clutter.ModifierType.BUTTON1_MASK |
                               Clutter.ModifierType.BUTTON2_MASK |
                               Clutter.ModifierType.BUTTON3_MASK;
             /* We only obey the last button release from the device,
              * other buttons may get pressed/released during the DnD op.
              */
-            return (event.get_state() & buttonMask) == 0;
-        } else if (event.type() == Clutter.EventType.TOUCH_END) {
+            return (event.get_state() & buttonMask) === 0;
+        } else if (event.type() === Clutter.EventType.TOUCH_END) {
             /* For touch, we only obey the pointer emulating sequence */
             return global.display.is_pointer_emulating_sequence(event.get_event_sequence());
         }
@@ -231,8 +291,8 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
         let device = event.get_device();
 
         if (this._grabbedDevice &&
-            device != this._grabbedDevice &&
-            device.get_device_type() != Clutter.InputDeviceType.KEYBOARD_DEVICE)
+            device !== this._grabbedDevice &&
+            device.get_device_type() !== Clutter.InputDeviceType.KEYBOARD_DEVICE)
             return Clutter.EVENT_PROPAGATE;
 
         // We intercept BUTTON_RELEASE event to know that the button was released in case we
@@ -240,9 +300,9 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
         // to complete the drag and ensure that whatever happens to be under the pointer does
         // not get triggered if the drag was cancelled with Esc.
         if (this._eventIsRelease(event)) {
-            if (this._dragState == DragState.DRAGGING) {
+            if (this._dragState === DragState.DRAGGING) {
                 return this._dragActorDropped(event);
-            } else if ((this._dragActor != null || this._dragState == DragState.CANCELLED) &&
+            } else if ((this._dragActor != null || this._dragState === DragState.CANCELLED) &&
                        !this._animationInProgress) {
                 // Drag must have been cancelled with Esc.
                 this._dragComplete();
@@ -254,19 +314,19 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
             }
         // We intercept MOTION event to figure out if the drag has started and to draw
         // this._dragActor under the pointer when dragging is in progress
-        } else if (event.type() == Clutter.EventType.MOTION ||
-                   (event.type() == Clutter.EventType.TOUCH_UPDATE &&
+        } else if (event.type() === Clutter.EventType.MOTION ||
+                   (event.type() === Clutter.EventType.TOUCH_UPDATE &&
                     global.display.is_pointer_emulating_sequence(event.get_event_sequence()))) {
-            if (this._dragActor && this._dragState == DragState.DRAGGING)
+            if (this._dragActor && this._dragState === DragState.DRAGGING)
                 return this._updateDragPosition(event);
-            else if (this._dragActor == null && this._dragState != DragState.CANCELLED)
+            else if (this._dragActor == null && this._dragState !== DragState.CANCELLED)
                 return this._maybeStartDrag(event);
 
         // We intercept KEY_PRESS event so that we can process Esc key press to cancel
         // dragging and ignore all other key presses.
-        } else if (event.type() == Clutter.EventType.KEY_PRESS && this._dragState == DragState.DRAGGING) {
+        } else if (event.type() === Clutter.EventType.KEY_PRESS && this._dragState === DragState.DRAGGING) {
             let symbol = event.get_key_symbol();
-            if (symbol == Clutter.KEY_Escape) {
+            if (symbol === Clutter.KEY_Escape) {
                 this._cancelDrag(event.get_time());
                 return Clutter.EVENT_STOP;
             }
@@ -276,8 +336,6 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
     }
 
     /**
-     * fakeRelease:
-     *
      * Fake a release event.
      * Must be called if you want to intercept release events on draggable
      * actors for other purposes (for example if you're using
@@ -288,28 +346,27 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
     }
 
     /**
-     * startDrag:
-     * @param {number} stageX: X coordinate of event
-     * @param {number} stageY: Y coordinate of event
-     * @param {number} time: Event timestamp
-     * @param {Clutter.EventSequence=} sequence: Event sequence
-     * @param {Clutter.InputDevice=} device: device that originated the event
-     *
      * Directly initiate a drag and drop operation from the given actor.
      * This function is useful to call if you've specified manualMode
      * for the draggable.
+     *
+     * @param {number} stageX - X coordinate of event
+     * @param {number} stageY - Y coordinate of event
+     * @param {number} time - Event timestamp
+     * @param {Clutter.EventSequence=} sequence - Event sequence
+     * @param {Clutter.InputDevice=} device - device that originated the event
      */
     startDrag(stageX, stageY, time, sequence, device) {
         if (currentDraggable)
             return;
 
-        if (device == undefined) {
+        if (device === undefined) {
             let event = Clutter.get_current_event();
 
             if (event)
                 device = event.get_device();
 
-            if (device == undefined) {
+            if (device === undefined) {
                 let seat = Clutter.get_default_backend().get_default_seat();
                 device = seat.get_pointer();
             }
@@ -419,11 +476,11 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
             this._finishAnimation();
 
             this._dragActor = null;
-            if (this._dragState == DragState.DRAGGING)
+            if (this._dragState === DragState.DRAGGING)
                 this._dragState = DragState.CANCELLED;
         });
         this._dragOrigOpacity = this._dragActor.opacity;
-        if (this._dragActorOpacity != undefined)
+        if (this._dragActorOpacity !== undefined)
             this._dragActor.opacity = this._dragActorOpacity;
 
         this._snapBackX = this._dragStartX + this._dragOffsetX;
@@ -440,7 +497,7 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
             this._dragX + this._dragOffsetX,
             this._dragY + this._dragOffsetY);
 
-        if (this._dragActorMaxSize != undefined) {
+        if (this._dragActorMaxSize !== undefined) {
             let currentSize = Math.max(scaledWidth, scaledHeight);
             if (currentSize > this._dragActorMaxSize) {
                 let scale = this._dragActorMaxSize / currentSize;
@@ -513,8 +570,8 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
     }
 
     _pickTargetActor() {
-        return this._dragActor.get_stage().get_actor_at_pos(Clutter.PickMode.ALL,
-                                                            this._dragX, this._dragY);
+        return this._dragActor.get_stage().get_actor_at_pos(
+            Clutter.PickMode.ALL, this._dragX, this._dragY);
     }
 
     _updateDragHover() {
@@ -544,7 +601,7 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
             let motionFunc = dragMonitors[i].dragMotion;
             if (motionFunc) {
                 let result = motionFunc(dragEvent);
-                if (result != DragMotionResult.CONTINUE) {
+                if (result !== DragMotionResult.CONTINUE) {
                     global.display.set_cursor(DRAG_CURSOR_MAP[result]);
                     dragEvent.targetActor.disconnect(targetActorDestroyHandlerId);
                     return GLib.SOURCE_REMOVE;
@@ -559,12 +616,13 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
                 // We currently loop through all parents on drag-over even if one of the children has handled it.
                 // We can check the return value of the function and break the loop if it's true if we don't want
                 // to continue checking the parents.
-                let result = target._delegate.handleDragOver(this.actor._delegate,
-                                                             this._dragActor,
-                                                             targX,
-                                                             targY,
-                                                             0);
-                if (result != DragMotionResult.CONTINUE) {
+                let result = target._delegate.handleDragOver(
+                    this.actor._delegate,
+                    this._dragActor,
+                    targX,
+                    targY,
+                    0);
+                if (result !== DragMotionResult.CONTINUE) {
                     global.display.set_cursor(DRAG_CURSOR_MAP[result]);
                     return GLib.SOURCE_REMOVE;
                 }
@@ -580,7 +638,7 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
             return;
 
         this._updateHoverId = GLib.idle_add(GLib.PRIORITY_DEFAULT,
-                                            this._updateDragHover.bind(this));
+            this._updateDragHover.bind(this));
         GLib.Source.set_name_by_id(this._updateHoverId, '[gnome-shell] this._updateDragHover');
     }
 
@@ -588,8 +646,9 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
         let [stageX, stageY] = event.get_coords();
         this._dragX = stageX;
         this._dragY = stageY;
-        this._dragActor.set_position(stageX + this._dragOffsetX,
-                                     stageY + this._dragOffsetY);
+        this._dragActor.set_position(
+            stageX + this._dragOffsetX,
+            stageY + this._dragOffsetY);
 
         this._queueUpdateDragHover();
         return true;
@@ -597,8 +656,8 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
 
     _dragActorDropped(event) {
         let [dropX, dropY] = event.get_coords();
-        let target = this._dragActor.get_stage().get_actor_at_pos(Clutter.PickMode.ALL,
-                                                                  dropX, dropY);
+        let target = this._dragActor.get_stage().get_actor_at_pos(
+            Clutter.PickMode.ALL, dropX, dropY);
 
         // We call observers only once per motion with the innermost
         // target actor. If necessary, the observer can walk the
@@ -635,12 +694,12 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
                         this._dragActor, targX, targY, event.get_time());
                 } catch (e) {
                     // On error, skip this target
-                    logError(e, "Skipping drag target");
+                    logError(e, 'Skipping drag target');
                 }
                 if (accepted) {
                     // If it accepted the drop without taking the actor,
                     // handle it ourselves.
-                    if (this._dragActor && this._dragActor.get_parent() == Main.uiGroup) {
+                    if (this._dragActor && this._dragActor.get_parent() === Main.uiGroup) {
                         if (this._restoreOnSuccess) {
                             this._restoreDragActor(event.get_time());
                             return true;
@@ -694,7 +753,7 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
 
     _cancelDrag(eventTime) {
         this.emit('drag-cancelled', eventTime);
-        let wasCancelled = this._dragState == DragState.CANCELLED;
+        let wasCancelled = this._dragState === DragState.CANCELLED;
         this._dragState = DragState.CANCELLED;
 
         if (this._actorDestroyed || wasCancelled) {
@@ -805,14 +864,9 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
         this._dragState = DragState.INIT;
         currentDraggable = null;
     }
-};
+}
 
 /**
- * makeDraggable:
- * @param {Clutter.Actor} actor: Source actor
- * @param {Object=} params: Additional parameters
- * @returns {Object} a new Draggable
- *
  * Create an object which controls drag and drop for the given actor.
  *
  * If %manualMode is %true in @params, do not automatically start
@@ -828,7 +882,11 @@ var _Draggable = class _Draggable extends Signals.EventEmitter {
  * succeeds, the actor scale and opacity aren't reset; if the drop
  * target wants to reuse the actor, it's up to the drop target to
  * reset these values.
+ *
+ * @param {Clutter.Actor} actor Source actor
+ * @param {object} [params] Additional parameters
+ * @returns {_Draggable} a new Draggable
  */
-function makeDraggable(actor, params) {
+export function makeDraggable(actor, params) {
     return new _Draggable(actor, params);
 }
