@@ -2,6 +2,8 @@
 
 #include <clutter/clutter.h>
 #include <meta/window.h>
+#include <mtk/mtk.h>
+
 #include "shell-window-preview-layout.h"
 
 typedef struct _ShellWindowPreviewLayoutPrivate ShellWindowPreviewLayoutPrivate;
@@ -155,7 +157,7 @@ shell_window_preview_layout_allocate (ClutterLayoutManager   *layout,
 
       if (window_info)
         {
-          MetaRectangle buffer_rect;
+          MtkRectangle buffer_rect;
           float child_nat_width, child_nat_height;
 
           meta_window_get_buffer_rect (window_info->window, &buffer_rect);
@@ -193,7 +195,7 @@ on_layout_changed (ShellWindowPreviewLayout *self)
   GHashTableIter iter;
   gpointer value;
   gboolean first_rect = TRUE;
-  MetaRectangle bounding_rect = { 0, };
+  MtkRectangle bounding_rect = { 0, };
   ClutterActorBox old_bounding_box;
 
   priv = shell_window_preview_layout_get_instance_private (self);
@@ -208,7 +210,7 @@ on_layout_changed (ShellWindowPreviewLayout *self)
   while (g_hash_table_iter_next (&iter, NULL, &value))
     {
       WindowInfo *window_info = value;
-      MetaRectangle frame_rect;
+      MtkRectangle frame_rect;
 
       meta_window_get_frame_rect (window_info->window, &frame_rect);
 
@@ -219,7 +221,7 @@ on_layout_changed (ShellWindowPreviewLayout *self)
           continue;
         }
 
-      meta_rectangle_union (&frame_rect, &bounding_rect, &bounding_rect);
+      mtk_rectangle_union (&frame_rect, &bounding_rect, &bounding_rect);
     }
 
   clutter_actor_box_set_origin (&priv->bounding_box,
